﻿<?xml version="1.0" encoding="utf-8"?>
<pattern id="Content" xmlns="http://purl.oclc.org/dsdl/schematron">
  <title>Content Validations</title>

  <rule context="xbrli:xbrl[not(@i:nil='true')]">

    <!-- Rule ID: VR.ATO.WRE.000066
         ELS Ref: V247B

		    IF ([wre46] > 250)
		       RETURN VALIDATION MESSAGE
		    ENDIF

		    [wre46] = rvctc2.xx.xx:IncomeTax.Deduction.EducationReduction.Amount
    -->
    <assert id="VR.ATO.WRE.000066" diagnostics="DVR.ATO.WRE.000066"
            test="not(
                        sum($wre46) > 250
                     )"/>
    
    
    <!-- Rule ID: VR.ATO.WRE.000067
         ELS Ref: V247A

		    IF ([wre47] <> NULL AND [wre47] <> (SUM([wre45]) - [wre46])) OR ([wre47] = NULL AND 
		    (SUM([wre45]) - [wre46]) <> 0)
		       RETURN VALIDATION MESSAGE
		    ENDIF

		    [wre45] = rvctc2.xx.xx:IncomeTax.Deduction.Education.Amount
		    [wre46] = rvctc2.xx.xx:IncomeTax.Deduction.EducationReduction.Amount
		    [wre47] = rvctc2.xx.xx:IncomeTax.Deduction.EducationNet.Amount
    -->
    <assert id="VR.ATO.WRE.000067" diagnostics="DVR.ATO.WRE.000067"
            test="not(
                       sum($wre47) != (sum($wre45) - sum($wre46))
                     )"/>
    
  </rule>
  
  <!-- LOOP OVER REPORTING PARTY CAR SEQUENCE DIMENSION CONTEXT -->
  <rule context="xbrli:xbrl/xbrli:context[@id = $RPCARSEQ.ContextId]">

    <let name="thisContextId" value="@id" />

    <!-- Rule ID: VR.ATO.WRE.000043
         ELS Ref: V205

		    WHERE IN CONTEXT(RP.CarSeqNum) 
		    IF ([wre15] = "12% of original value" AND ([wre22] > ([wre19] * 0.12) + 1))
		       RETURN VALIDATION MESSAGE
		    ENDIF

		    [wre15] = rvctc2.xx.xx:IncomeTax.Deduction.CarCalculationMethod.Code
		    [wre19] = bafpr1.xx.xx:Expense.CarPurchasePrice.Amount
		    [wre22] = rvctc2.xx.xx:IncomeTax.Deduction.Car.Amount
    -->
    <assert id="VR.ATO.WRE.000043" diagnostics="DVR.ATO.WRE.000043"
            test="not(
                        $wre15[. = '12% of original value' and @contextRef = $thisContextId]
                        and
                        sum($wre22[@contextRef = $thisContextId]) 
                        >
                        (sum($wre19[@contextRef = $thisContextId]) * 0.12) + 1                            
                     )"/>


    <!-- Rule ID: VR.ATO.WRE.000044
         ELS Ref: V198B

		    WHERE IN CONTEXT(RP.CarSeqNum) 
		    IF ([wre17] <> NULL AND [wre16] = NULL)
		       RETURN VALIDATION MESSAGE
		    ENDIF

		    [wre16] = rvctc2.xx.xx:IncomeTax.Deduction.CarLogBookMethodBusinessUseRecorded.Percent
		    [wre17] = rvctc2.xx.xx:IncomeTax.Deduction.CarLogBookMethodBusinessUseClaimed.Percent
    -->
    <assert id="VR.ATO.WRE.000044" diagnostics="DVR.ATO.WRE.000044"
            test="not(
                        $wre17[not(@i:nil='true') and @contextRef = $thisContextId]
                        and
                        not($wre16[not(@i:nil='true') and @contextRef = $thisContextId])                         
                     )"/>


    <!-- Rule ID: VR.ATO.WRE.000045
         ELS Ref: V1374

		    WHERE IN CONTEXT(RP.CarSeqNum) 
		    IF ([wre15] = "Logbook" AND [wre16] = NULL)
		       RETURN VALIDATION MESSAGE
		    ENDIF

		    [wre15] = rvctc2.xx.xx:IncomeTax.Deduction.CarCalculationMethod.Code
		    [wre16] = rvctc2.xx.xx:IncomeTax.Deduction.CarLogBookMethodBusinessUseRecorded.Percent
    -->
    <assert id="VR.ATO.WRE.000045" diagnostics="DVR.ATO.WRE.000045"
            test="not(
                        $wre15[. = 'Logbook' and @contextRef = $thisContextId]
                        and
                        not($wre16[not(@i:nil='true') and @contextRef = $thisContextId])                         
                     )"/>


    <!-- Rule ID: VR.ATO.WRE.000046
         ELS Ref: V198A

		    WHERE IN CONTEXT(RP.CarSeqNum) 
		    IF ([wre16] <> NULL AND [wre17] = NULL)
		       RETURN VALIDATION MESSAGE
		    ENDIF

		    [wre16] = rvctc2.xx.xx:IncomeTax.Deduction.CarLogBookMethodBusinessUseRecorded.Percent
		    [wre17] = rvctc2.xx.xx:IncomeTax.Deduction.CarLogBookMethodBusinessUseClaimed.Percent
    -->
    <assert id="VR.ATO.WRE.000046" diagnostics="DVR.ATO.WRE.000046"
            test="not(
                        $wre16[not(@i:nil='true') and @contextRef = $thisContextId]
                        and
                        not($wre17[not(@i:nil='true') and @contextRef = $thisContextId])
                     )"/>


    <!-- Rule ID: VR.ATO.WRE.000047
         ELS Ref: V195

		    WHERE IN CONTEXT(RP.CarSeqNum) 
		    IF ([wre15] = "Cents per kilometre" AND [wre18] > 5000)
		       RETURN VALIDATION MESSAGE
		    ENDIF

		    [wre15] = rvctc2.xx.xx:IncomeTax.Deduction.CarCalculationMethod.Code
		    [wre18] = rvctc2.xx.xx:IncomeTax.Deduction.CarBusinessKilometres.Number
    -->
    <assert id="VR.ATO.WRE.000047" diagnostics="DVR.ATO.WRE.000047"
            test="not(
                        $wre15[. = 'Cents per kilometre' and @contextRef = $thisContextId]
                        and
                        sum($wre18[@contextRef = $thisContextId]) > 5000
                     )"/>


    <!-- Rule ID: VR.ATO.WRE.000048
         ELS Ref: V204

		    IF (ANY OCCURRENCE OF ([wre19] > 57466))
		       RETURN VALIDATION MESSAGE
		    ENDIF

		    [wre19] = bafpr1.xx.xx:Expense.CarPurchasePrice.Amount
    -->
    <assert id="VR.ATO.WRE.000048" diagnostics="DVR.ATO.WRE.000048"
            test="not(
                        sum($wre19[@contextRef = $thisContextId]) > 57466
                     )"/>


    <!-- Rule ID: VR.ATO.WRE.000049
         ELS Ref: V231

		    WHERE IN CONTEXT(RP.CarSeqNum)
		    IF  (
                [wre15] = SET("12% of original value", "One-third of actual expenses", "Logbook") 
                AND 
                [wre20] <> SET("Invoice receipt", "PAYG summary", "Dairy evidence", "Allowance", "ATO ruling", "Diary calculation", "Actual recorded cost", "Log book", "Other evidence", "Other calculation")
            )
		       RETURN VALIDATION MESSAGE
		    ENDIF

		    [wre15] = rvctc2.xx.xx:IncomeTax.Deduction.CarCalculationMethod.Code
		    [wre20] = rvctc2.xx.xx:IncomeTax.Deduction.CarStandardEvidenceCalculation.Code
    -->
    <assert id="VR.ATO.WRE.000049" diagnostics="DVR.ATO.WRE.000049"
            test="not(
                        $wre15
                        [
                            (
                                . = '12% of original value'    or . = 'One-third of actual expenses'  or . = 'Logbook'
                            )
                            and
                            @contextRef = $thisContextId
                        ]
                        and
                        $wre20
                        [
                            not
                            (
                                . = 'Invoice receipt'       or . = 'PAYG summary'   or . = 'Diary evidence'     or 
                                . = 'Allowance'             or . = 'ATO ruling'     or . = 'Diary calculation'  or
                                . = 'Actual recorded cost'  or . = 'Log book'       or . = 'Other evidence'     or 
                                . = 'Other calculation'
                            )
                            and
                            @contextRef = $thisContextId
                        ]
                     )"/>


    <!-- Rule ID: VR.ATO.WRE.000051
         ELS Ref: V249

		    WHERE IN CONTEXT(RP.CarSeqNum)
		    IF ([wre20] = SET("Other evidence", "Other calculation") AND [wre21] = NULLORBLANK)
		       RETURN VALIDATION MESSAGE
		    ENDIF

		    [wre20] = rvctc2.xx.xx:IncomeTax.Deduction.CarStandardEvidenceCalculation.Code
		    [wre21] = rvctc2.xx.xx:IncomeTax.Deduction.CarStandardEvidenceCalculationOther.Description
    -->
    <assert id="VR.ATO.WRE.000051" diagnostics="DVR.ATO.WRE.000051"
            test="not(
                        $wre20
                        [
                            (. = 'Other evidence' or . = 'Other calculation')
                            and
                            @contextRef = $thisContextId
                        ]
                        and
                        not($wre21[not(@i:nil='true') and string-length(.) != 0 and @contextRef = $thisContextId])
                     )"/>


    <!-- Rule ID: VR.ATO.WRE.000052
         ELS Ref: V196A

		    WHERE IN CONTEXT(RP.CarSeqNum)
		    IF (([wre14] = "A" AND [wre15] = "Cents per kilometre") AND (([wre18] * 0.65) +/- 1) <> [wre22])
		       RETURN VALIDATION MESSAGE
		    ENDIF

		    [wre14] = rvctc2.xx.xx:IncomeTax.Deduction.CarEngineCapacity.Code
		    [wre15] = rvctc2.xx.xx:IncomeTax.Deduction.CarCalculationMethod.Code
		    [wre18] = rvctc2.xx.xx:IncomeTax.Deduction.CarBusinessKilometres.Number
		    [wre22] = rvctc2.xx.xx:IncomeTax.Deduction.Car.Amount
    -->
    <assert id="VR.ATO.WRE.000052" diagnostics="DVR.ATO.WRE.000052"
            test="not(
                        $wre14[. = 'A' and @contextRef = $thisContextId]
                        and
                        $wre15[. = 'Cents per kilometre' and @contextRef = $thisContextId]
                        and
                        (
	                          sum($wre22[@contextRef = $thisContextId]) &lt; (sum($wre18[@contextRef = $thisContextId]) * 0.65) - 1
                            or
                            sum($wre22[@contextRef = $thisContextId]) > (sum($wre18[@contextRef = $thisContextId]) * 0.65) + 1
                        )
                     )"/>
    

    <!-- Rule ID: VR.ATO.WRE.000053
         ELS Ref: V196B

		    WHERE IN CONTEXT(RP.CarSeqNum) 
		    IF (([wre14] = "B" AND [wre15] = "Cents per kilometre") AND (([wre18] * 0.76) +/- 1) <> [wre22])
		       RETURN VALIDATION MESSAGE
		    ENDIF

		    [wre14] = rvctc2.xx.xx:IncomeTax.Deduction.CarEngineCapacity.Code
		    [wre15] = rvctc2.xx.xx:IncomeTax.Deduction.CarCalculationMethod.Code
		    [wre18] = rvctc2.xx.xx:IncomeTax.Deduction.CarBusinessKilometres.Number
		    [wre22] = rvctc2.xx.xx:IncomeTax.Deduction.Car.Amount
    -->
    <assert id="VR.ATO.WRE.000053" diagnostics="DVR.ATO.WRE.000053"
            test="not(
                        $wre14[. = 'B' and @contextRef = $thisContextId]
                        and
                        $wre15[. = 'Cents per kilometre' and @contextRef = $thisContextId]
                        and
                        (
	                          sum($wre22[@contextRef = $thisContextId]) &lt; (sum($wre18[@contextRef = $thisContextId]) * 0.76) - 1
                            or
                            sum($wre22[@contextRef = $thisContextId]) > (sum($wre18[@contextRef = $thisContextId]) * 0.76) + 1
                        )
                     )"/>


    <!-- Rule ID: VR.ATO.WRE.000054
         ELS Ref: V196C

		    WHERE IN CONTEXT(RP.CarSeqNum) 
		    IF (([wre14] = "C" AND [wre15] = "Cents per kilometre") AND (([wre18] * 0.77) +/- 1) <> [wre22])
		       RETURN VALIDATION MESSAGE
		    ENDIF

		    [wre14] = rvctc2.xx.xx:IncomeTax.Deduction.CarEngineCapacity.Code
		    [wre15] = rvctc2.xx.xx:IncomeTax.Deduction.CarCalculationMethod.Code
		    [wre18] = rvctc2.xx.xx:IncomeTax.Deduction.CarBusinessKilometres.Number
		    [wre22] = rvctc2.xx.xx:IncomeTax.Deduction.Car.Amount
    -->
    <assert id="VR.ATO.WRE.000054" diagnostics="DVR.ATO.WRE.000054"
            test="not(
                        $wre14[. = 'C' and @contextRef = $thisContextId]
                        and
                        $wre15[. = 'Cents per kilometre' and @contextRef = $thisContextId]
                        and
                        (
	                          sum($wre22[@contextRef = $thisContextId]) &lt; (sum($wre18[@contextRef = $thisContextId]) * 0.77) - 1
                            or
                            sum($wre22[@contextRef = $thisContextId]) > (sum($wre18[@contextRef = $thisContextId]) * 0.77) + 1
                        )
                     )"/>
  </rule>

  <!-- LOOP OVER REPORTING PARTY TRAVEL SEQUENCE DIMENSION CONTEXT -->
  <rule context="xbrli:xbrl/xbrli:context[@id = $RPTRAVELSEQ.ContextId]">

    <let name="thisContextId" value="@id" />

    <!-- Rule ID: VR.ATO.WRE.000056
         ELS Ref: V233

        WHERE IN CONTEXT(RP.{TrvlSeqNum}) 
        IF ([wre25] = SET("Vehicles", "Other") 
            AND 
            [wre27] <> SET("Invoice receipt", "PAYG summary", "Diary evidence", "Allowance", "No Substantiation", "Other evidence"))
          RETURN VALIDATION MESSAGE
		    ENDIF

		    [wre25] = rvctc2.xx.xx:IncomeTax.Deduction.TravelCategory.Code
		    [wre27] = rvctc2.xx.xx:IncomeTax.Deduction.TravelStandardEvidenceCalculation.Code
    -->
    <assert id="VR.ATO.WRE.000056" diagnostics="DVR.ATO.WRE.000056"
            test="not(
                        $wre25
                        [
                            (
                                . = 'Vehicles' or . = 'Other'
                            )
                            and
                            @contextRef = $thisContextId
                        ]
                        and
                        $wre27
                        [
                            not
                            (
                                . = 'Invoice receipt' or . = 'PAYG summary'   or . = 'Diary evidence' or 
                                . = 'Allowance'       or . = 'No Substantiation' or . = 'Other evidence'
                            )
                            and
                            @contextRef = $thisContextId
                        ]
                     )"/>


    <!-- Rule ID: VR.ATO.WRE.000057
         ELS Ref: V236

		    WHERE IN CONTEXT(RP.TrvlSeqNum) 
		    IF ([wre25] = SET("Award", "Domestic", "Overseas") AND [wre27] = NULLORBLANK)
		       RETURN VALIDATION MESSAGE
		    ENDIF

		    [wre25] = rvctc2.xx.xx:IncomeTax.Deduction.TravelCategory.Code
		    [wre27] = rvctc2.xx.xx:IncomeTax.Deduction.TravelStandardEvidenceCalculation.Code
    -->
    <assert id="VR.ATO.WRE.000057" diagnostics="DVR.ATO.WRE.000057"
            test="not(
                        $wre25
                        [
                            (. = 'Award' or . = 'Domestic' or . = 'Overseas')
                            and
                            @contextRef = $thisContextId
                        ]
                        and
                        not($wre27[not(@i:nil='true') and string-length(.) != 0 and @contextRef = $thisContextId])
                     )"/>


    <!-- Rule ID: VR.ATO.WRE.000058
         ELS Ref: V184

		    WHERE IN CONTEXT(RP.TrvlSeqNum) 
		    IF ([wre27] = SET("Other evidence", "Other calculation") AND [wre28] = NULLORBLANK)
		       RETURN VALIDATION MESSAGE
		    ENDIF

		    [wre27] = rvctc2.xx.xx:IncomeTax.Deduction.TravelStandardEvidenceCalculation.Code
		    [wre28] = rvctc2.xx.xx:IncomeTax.Deduction.TravelStandardEvidenceCalculationOther.Description
    -->
    <assert id="VR.ATO.WRE.000058" diagnostics="DVR.ATO.WRE.000058"
            test="not(
                        $wre27
                        [
                            (. = 'Other evidence' or . = 'Other calculation')
                            and
                            @contextRef = $thisContextId
                        ]
                        and
                        not($wre28[not(@i:nil='true') and string-length(.) != 0 and @contextRef = $thisContextId])
                     )"/>
    
    
    <!-- Rule ID: VR.ATO.WRE.000085
         ELS Ref: N/A

		     WHERE IN RP.{TrvlSeqNum}
         IF [wre25] = "Other" AND [wre26] = NULLORBLANK
           RETURN VALIDATION MESSAGE
         ENDIF

         [wre25] = rvctc2.xx.xx:IncomeTax.Deduction.TravelCategory.Code
		     [wre26] = rvctc2.xx.xx:IncomeTax.Deduction.TravelCategoryOther.Description
    -->
    <assert id="VR.ATO.WRE.000085" diagnostics="DVR.ATO.WRE.000085"
            test="not(
                        $wre25
                        [
                            (. = 'Other')
                            and
                            @contextRef = $thisContextId
                        ]
                        and
                        not($wre26[not(@i:nil='true') and string-length(.) != 0 and @contextRef = $thisContextId])
                     )"/>

  </rule>

  <!-- LOOP OVER REPORTING PARTY CLOTHING SEQUENCE DIMENSION CONTEXT -->
  <rule context="xbrli:xbrl/xbrli:context[@id = $RPCLOTHINGSEQ.ContextId]">

    <let name="thisContextId" value="@id" />

    <!-- Rule ID: VR.ATO.WRE.000060
         ELS Ref: V242

		    WHERE IN CONTEXT(RP.ClthngSeqNum) 
		    IF ([wre32] = "Laundry" AND [wre34] = NULLORBLANK)
		       RETURN VALIDATION MESSAGE
		    ENDIF

		    [wre32] = rvctc2.xx.xx:IncomeTax.Deduction.ClothingCategory.Code
		    [wre34] = rvctc2.xx.xx:IncomeTax.Deduction.ClothingStandardEvidenceCalculation.Code
    -->
    <assert id="VR.ATO.WRE.000060" diagnostics="DVR.ATO.WRE.000060"
            test="not(
                        $wre32
                        [
                            . = 'Laundry'
                            and
                            @contextRef = $thisContextId
                        ]
                        and
                        not($wre34[not(@i:nil='true') and string-length(.) != 0 and @contextRef = $thisContextId])
                     )"/>


    <!-- Rule ID: VR.ATO.WRE.000061
         ELS Ref: V244

        WHERE IN CONTEXT(RP.{ClthngSeqNum}) 
        IF ([wre32] = SET("Dry cleaning", "Protective clothing", "Compulsory work uniform", "Non-compulsory work uniform", "Occupation specific clothing", "Other") 
            AND 
            [wre34] <> SET("Invoice receipt", "PAYG summary", "Diary evidence", "Allowance", "No Substantiation", "Other evidence"))
          RETURN VALIDATION MESSAGE
		    ENDIF

		    [wre32] = rvctc2.xx.xx:IncomeTax.Deduction.ClothingCategory.Code
		    [wre34] = rvctc2.xx.xx:IncomeTax.Deduction.ClothingStandardEvidenceCalculation.Code
    -->
    <assert id="VR.ATO.WRE.000061" diagnostics="DVR.ATO.WRE.000061"
            test="not(
                        $wre32
                        [
                            (
                                . = 'Dry cleaning'                or . = 'Protective clothing'          or . = 'Compulsory work uniform' or 
                                . = 'Non-compulsory work uniform' or . = 'Occupation specific clothing' or . = 'Other'
                            )
                            and
                            @contextRef = $thisContextId
                        ]
                        and
                        $wre34
                        [
                            not
                            (
                                . = 'Invoice receipt' or . = 'PAYG summary'   or . = 'Diary evidence' or 
                                . = 'Allowance'       or . = 'No Substantiation' or . = 'Other evidence'
                            )
                            and
                            @contextRef = $thisContextId
                        ]
                     )"/>


    <!-- Rule ID: VR.ATO.WRE.000062
         ELS Ref: V192

		    WHERE IN CONTEXT(RP.ClthngSeqNum) 
		    IF ([wre34] = SET("Other evidence", "Other calculation") AND [wre35] = NULLORBLANK)
		       RETURN VALIDATION MESSAGE
		    ENDIF

		    [wre34] = rvctc2.xx.xx:IncomeTax.Deduction.ClothingStandardEvidenceCalculation.Code
		    [wre35] = rvctc2.xx.xx:IncomeTax.Deduction.ClothingStandardEvidenceCalculationOther.Description
    -->
    <assert id="VR.ATO.WRE.000062" diagnostics="DVR.ATO.WRE.000062"
            test="not(
                        $wre34
                        [
                            (. = 'Other evidence' or . = 'Other calculation')
                            and
                            @contextRef = $thisContextId
                        ]
                        and
                        not($wre35[not(@i:nil='true') and string-length(.) != 0 and @contextRef = $thisContextId])
                     )"/>    
    
    
    <!-- Rule ID: VR.ATO.WRE.000086
         ELS Ref: N/A

		     WHERE IN RP.{ClthngSeqNum}
         IF [wre32] = "Other" AND [wre33] = NULLORBLANK
            RETURN VALIDATION MESSAGE
         ENDIF

         [wre32] = rvctc2.xx.xx:IncomeTax.Deduction.ClothingCategory.Code
		     [wre33] = rvctc2.xx.xx:IncomeTax.Deduction.ClothingCategoryOther.Description
    -->
    <assert id="VR.ATO.WRE.000086" diagnostics="DVR.ATO.WRE.000086"
            test="not(
                        $wre32
                        [
                            (. = 'Other')
                            and
                            @contextRef = $thisContextId
                        ]
                        and
                        not($wre33[not(@i:nil='true') and string-length(.) != 0 and @contextRef = $thisContextId])
                     )"/>

  </rule>

    <!-- Rule ID: VR.ATO.WRE.000050
         ELS Ref: V232A

		    Removed as handled by XBRL validation. Defect ID: 122843
    -->

    <!-- Rule ID: VR.ATO.WRE.000055
         ELS Ref: V232B

		    Removed as handled by XBRL validation. Defect ID: 122843
    -->

  	<!-- Rule ID: VR.ATO.WRE.000064
         ELS Ref: V232D

		    Removed as handled by XBRL validation. Defect ID: 122843
    -->

  	<!-- Rule ID: VR.ATO.WRE.000069
         ELS Ref: V232D

        Removed as handled by XBRL validation. Defect ID: 122843
    -->


    <!-- Rule ID: VR.ATO.WRE.000059
         ELS Ref: V232C

		    Removed as handled by XBRL validation. Defect ID: 122843
    -->
  
  <!-- LOOP OVER REPORTING PARTY OTHER WRE SEQUENCE DIMENSION CONTEXT -->
  <rule context="xbrli:xbrl/xbrli:context[@id = $RPOTHERWRESEQ.ContextId]">

    <let name="thisContextId" value="@id" />
    
    <!-- Rule ID: VR.ATO.WRE.000068
         ELS Ref: V217

        WHERE IN CONTEXT(RP.{OTHWRSeqNum}) 
        IF ([wre50] = SET("Home Telephone", "Computer expenses") AND [wre52] = NULL)
           RETURN VALIDATION MESSAGE
        ENDIF

		    [wre50] = rvctc2.xx.xx:IncomeTax.Deduction.WorkRelatedCategoryOther.Code
		    [wre52] = rvctc2.xx.xx:IncomeTax.Deduction.WorkRelatedBusinessUseClaimedOther.Percent
    -->
    <assert id="VR.ATO.WRE.000068" diagnostics="DVR.ATO.WRE.000068"
            test="not(
                        $wre50[(. = 'Home Telephone' or . = 'Computer expenses') and @contextRef = $thisContextId]
                        and
                        not($wre52[@contextRef = $thisContextId and not(@i:nil='true')])
                     )"/>

    
    <!-- Rule ID: VR.ATO.WRE.000070
         ELS Ref: V248

        WHERE IN CONTEXT(RP.{OTHWRSeqNum}) 
        IF (
          [wre50] = SET("Seminars", "Books and journals", "Home office running", "Home office occupancy", "Home Telephone", "Computer expenses", "Tools and equipment", "Other depreciation", "Other", "Newspapers", "Mobile Phone", "Internet Access", "Subscriptions", "Printing Postage and Stationery") 
          AND 
          [wre53] <> SET("Invoice receipt", "PAYG summary", "Diary evidence", "Allowance", "No Substantiation", "Other evidence")
        )
            RETURN VALIDATION MESSAGE
        ENDIF

        
		    [wre50] = rvctc2.xx.xx:IncomeTax.Deduction.WorkRelatedCategoryOther.Code
		    [wre53] = rvctc2.xx.xx:IncomeTax.Deduction.WorkRelatedStandardEvidenceCalculationOther.Code
    -->
    <assert id="VR.ATO.WRE.000070" diagnostics="DVR.ATO.WRE.000070"
            test="not(
                        $wre50
                        [
                          (. = 'Seminars' or . = 'Books and journals' or . = 'Home office running' or 
                           . = 'Home office occupancy' or . = 'Home Telephone' or . = 'Computer expenses' or
                           . = 'Tools and equipment' or . = 'Other depreciation' or . = 'Other' or . = 'Newspapers' or . = 'Mobile Phone' or 
                           . = 'Internet Access' or . = 'Subscriptions' or . = 'Printing Postage and Stationery') 
                          and 
                          @contextRef = $thisContextId
                        ]
                        and
                        not($wre53
                        [
                          (. = 'Invoice receipt' or . = 'PAYG summary' or . = 'Diary evidence' or . = 'Allowance' or 
                           . = 'No Substantiation' or . = 'Other evidence')
                          and 
                          @contextRef = $thisContextId
                        ])
                     )"/>

    
    <!-- Rule ID: VR.ATO.WRE.000071
         ELS Ref: V217

		    WHERE IN CONTEXT(RP.OTHWRSeqNum)
		    IF ([wre53] = SET("Other evidence", "Other calculation") AND [wre54] = NULLORBLANK)
		       RETURN VALIDATION MESSAGE
		    ENDIF

		    [wre53] = rvctc2.xx.xx:IncomeTax.Deduction.WorkRelatedStandardEvidenceCalculationOther.Code
		    [wre54] = rvctc2.xx.xx:IncomeTax.Deduction.WorkRelatedStandardEvidenceCalculationOther.Description
    -->
    <assert id="VR.ATO.WRE.000071" diagnostics="DVR.ATO.WRE.000071"
            test="not(
                        $wre53[(. = 'Other evidence' or . = 'Other calculation') and @contextRef = $thisContextId]
                        and
                        not($wre54[@contextRef = $thisContextId and not(@i:nil='true') and string-length(.) != 0])              
                     )"/>
    
    
    <!-- Rule ID: VR.ATO.WRE.000088
         ELS Ref: N/A

		     WHERE IN RP.{OTHWRSeqNum}
         IF [wre50] = "Other" AND [wre51] = NULLORBLANK
           RETURN VALIDATION MESSAGE
         ENDIF

         [wre50] = rvctc2.xx.xx:IncomeTax.Deduction.WorkRelatedCategoryOther.Code
		     [wre51] = rvctc2.xx.xx:IncomeTax.Deduction.WorkRelatedCategoryOther.Description
    -->
    <assert id="VR.ATO.WRE.000088" diagnostics="DVR.ATO.WRE.000088"
            test="not(
                        $wre50
                        [
                            (. = 'Other')
                            and
                            @contextRef = $thisContextId
                        ]
                        and
                        not($wre51[not(@i:nil='true') and string-length(.) != 0 and @contextRef = $thisContextId])
                     )"/>
    
  </rule>
  
  <!-- LOOP OVER REPORTING PARTY EDUCATION SEQUENCE DIMENSION CONTEXT -->
  <rule context="xbrli:xbrl/xbrli:context[@id = $RPEDUCATIONSEQ.ContextId]">

    <let name="thisContextId" value="@id" />

    <!-- Rule ID: VR.ATO.WRE.000063
         ELS Ref: V221

		    WHERE IN CONTEXT(RP.EduSeqNum)
		    IF ([wre41] <> NULLORBLANK AND [wre43] = NULLORBLANK)
		       RETURN VALIDATION MESSAGE
		    ENDIF

		    [wre41] = rvctc2.xx.xx:IncomeTax.Deduction.EducationCategory.Code
		    [wre43] = rvctc2.xx.xx:IncomeTax.Deduction.EducationStandardEvidenceCalculation.Code
    -->
    <assert id="VR.ATO.WRE.000063" diagnostics="DVR.ATO.WRE.000063"
            test="not(
                        $wre41[@contextRef = $thisContextId and not(@i:nil='true') and string-length(.) != 0]
                        and
                        not($wre43[@contextRef = $thisContextId and not(@i:nil='true') and string-length(.) != 0])              
                     )"/>
    
    <!-- Rule ID: VR.ATO.WRE.000065
         ELS Ref: V214

		    WHERE IN CONTEXT(RP.EduSeqNum) 
		    IF ([wre43] = SET("Other evidence", "Other calculation") AND [wre44] = NULLORBLANK)
		       RETURN VALIDATION MESSAGE
		    ENDIF

		    [wre43] = rvctc2.xx.xx:IncomeTax.Deduction.EducationStandardEvidenceCalculation.Code
		    [wre44] = rvctc2.xx.xx:IncomeTax.Deduction.EducationStandardEvidenceCalculationOther.Description
    -->
    <assert id="VR.ATO.WRE.000065" diagnostics="DVR.ATO.WRE.000065"
            test="not(
                        $wre43[(. = 'Other evidence' or . = 'Other calculation') and @contextRef = $thisContextId]
                        and
                        not($wre44[@contextRef = $thisContextId and not(@i:nil='true') and string-length(.) != 0])              
                     )"/>  
    
    
    <!-- Rule ID: VR.ATO.WRE.000087
         ELS Ref: N/A

		     WHERE IN RP.{EduSeqNum}
         IF [wre41] = "Other" AND [wre42] = NULLORBLANK
            RETURN VALIDATION MESSAGE
         ENDIF

         [wre41] = rvctc2.xx.xx:IncomeTax.Deduction.EducationCategory.Code
		     [wre42] = rvctc2.xx.xx:IncomeTax.Deduction.EducationCategoryOther.Description
    -->
    <assert id="VR.ATO.WRE.000087" diagnostics="DVR.ATO.WRE.000087"
            test="not(
                        $wre41
                        [
                            (. = 'Other')
                            and
                            @contextRef = $thisContextId
                        ]
                        and
                        not($wre42[not(@i:nil='true') and string-length(.) != 0 and @contextRef = $thisContextId])
                     )"/>
  </rule>

</pattern>
