﻿<?xml version="1.0" encoding="utf-8"?>
<pattern id="FieldPatterns" xmlns="http://purl.oclc.org/dsdl/schematron">
  <title>Field Length Validations</title>

  <rule context="xbrli:xbrl[not(@i:nil='true')]">

    <!-- Rule ID: VR.ATO.WRE.000020
         ELS Ref: V7

		    IF ([wre46] <> MONETARY(U,11,0))
		         RETURN VALIDATION MESSAGE
		    ENDIF

		    [wre46] = rvctc2.xx.xx:IncomeTax.Deduction.EducationReduction.Amount
    -->
    <assert id="VR.ATO.WRE.000020" diagnostics="DVR.ATO.WRE.000020"
            test="not(
                          $wre46
                          [
                              not(matches(.,'^[0-9]{1,11}$'))
                          ]
                       )"/>
    
    <!-- Rule ID: VR.ATO.WRE.000021
         ELS Ref: V7

		    IF ([wre47] <> MONETARY(U,11,0))
		         RETURN VALIDATION MESSAGE
		    ENDIF

		    [wre47] = rvctc2.xx.xx:IncomeTax.Deduction.EducationNet.Amount
    -->
    <assert id="VR.ATO.WRE.000021" diagnostics="DVR.ATO.WRE.000021"
            test="not(
                          $wre47
                          [
                              not(matches(.,'^[0-9]{1,11}$'))
                          ]
                       )"/>
    
  </rule>
  
  <!-- LOOP OVER REPORTING PARTY CAR SEQUENCE DIMENSION CONTEXT -->
  <rule context="xbrli:xbrl/xbrli:context[@id = $RPCARSEQ.ContextId]">

    <let name="thisContextId" value="@id" />

    <!-- Rule ID: VR.ATO.WRE.000001
         ELS Ref: V7

		    IF (LENGTH([wre13])) > 20
             RETURN VALIDATION MESSAGE
        ENDIF

		    [wre13] = bafpo1.xx.xx:Assets.CarMakeModel.Description
    -->
    <assert id="VR.ATO.WRE.000001" diagnostics="DVR.ATO.WRE.000001"
            test="not(
                        $wre13
                        [
                            string-length(.) > 20
                            and
                            @contextRef = $thisContextId
                        ]
                     )"/>


    <!-- Rule ID: VR.ATO.WRE.000002
         ELS Ref: V7

		    IF ANY OCCURRENCE OF (LENGTH([wre16])) > 3
		         RETURN VALIDATION MESSAGE
		    ENDIF

		    [wre16] = rvctc2.xx.xx:IncomeTax.Deduction.CarLogBookMethodBusinessUseRecorded.Percent
    -->
    <assert id="VR.ATO.WRE.000002" diagnostics="DVR.ATO.WRE.000002"
            test="not(
                        $wre16
                        [
                            string-length(.) > 3
                            and
                            @contextRef = $thisContextId
                        ]
                     )"/>


    <!-- Rule ID: VR.ATO.WRE.000003
         ELS Ref: V7

		    IF ANY OCCURRENCE OF (LENGTH([wre17])) > 3
		         RETURN VALIDATION MESSAGE
		    ENDIF

		    [wre17] = rvctc2.xx.xx:IncomeTax.Deduction.CarLogBookMethodBusinessUseClaimed.Percent
    -->
    <assert id="VR.ATO.WRE.000003" diagnostics="DVR.ATO.WRE.000003"
            test="not(
                        $wre17
                        [
                            string-length(.) > 3
                            and
                            @contextRef = $thisContextId
                        ]
                     )"/>


    <!-- Rule ID: VR.ATO.WRE.000004
         ELS Ref: V7

		    IF ANY OCCURRENCE OF (LENGTH([wre18])) > 4
		         RETURN VALIDATION MESSAGE
		    ENDIF

		    [wre18] = rvctc2.xx.xx:IncomeTax.Deduction.CarBusinessKilometres.Number
    -->
    <assert id="VR.ATO.WRE.000004" diagnostics="DVR.ATO.WRE.000004"
            test="not(
                        $wre18
                        [
                            string-length(.) > 4
                            and
                            @contextRef = $thisContextId
                        ]
                     )"/>
    

    <!-- Rule ID: VR.ATO.WRE.000005
         ELS Ref: V7

		    IF ANY OCCURRENCE OF ([wre19] <> MONETARY(U,11,0))
		         RETURN VALIDATION MESSAGE
		    ENDIF

		    [wre19] = bafpr1.xx.xx:Expense.CarPurchasePrice.Amount
    -->
    <assert id="VR.ATO.WRE.000005" diagnostics="DVR.ATO.WRE.000005"
            test="not(
                        $wre19
                        [
                            not(matches(.,'^[0-9]{1,11}$'))
                            and
                            @contextRef = $thisContextId
                        ]
                     )"/>


    <!-- Rule ID: VR.ATO.WRE.000006
         ELS Ref: V7

		    IF (LENGTH([wre21])) > 240
             RETURN VALIDATION MESSAGE
        ENDIF

		    [wre21] = rvctc2.xx.xx:IncomeTax.Deduction.CarStandardEvidenceCalculationOther.Description
    -->
    <assert id="VR.ATO.WRE.000006" diagnostics="DVR.ATO.WRE.000006"
            test="not(
                        $wre21
                        [
                            string-length(.) > 240
                            and
                            @contextRef = $thisContextId
                        ]
                     )"/>


    <!-- Rule ID: VR.ATO.WRE.000007
         ELS Ref: V7

		    IF ANY OCCURRENCE OF ([wre22] <> MONETARY(U,11,0))
		         RETURN VALIDATION MESSAGE
		    ENDIF

		    [wre22] = rvctc2.xx.xx:IncomeTax.Deduction.Car.Amount
    -->
    <assert id="VR.ATO.WRE.000007" diagnostics="DVR.ATO.WRE.000007"
            test="not(
                        $wre22
                        [
                            not(matches(.,'^[0-9]{1,11}$'))
                            and
                            @contextRef = $thisContextId
                        ]
                     )"/>

  </rule>

  <!-- LOOP OVER REPORTING PARTY TRAVEL SEQUENCE DIMENSION CONTEXT -->
  <rule context="xbrli:xbrl/xbrli:context[@id = $RPTRAVELSEQ.ContextId]">

    <let name="thisContextId" value="@id" />

    <!-- Rule ID: VR.ATO.WRE.000008
         ELS Ref: V7

		    IF (LENGTH([wre26])) > 40
             RETURN VALIDATION MESSAGE
        ENDIF

		    [wre26] = rvctc2.xx.xx:IncomeTax.Deduction.TravelCategoryOther.Description
    -->
    <assert id="VR.ATO.WRE.000008" diagnostics="DVR.ATO.WRE.000008"
            test="not(
                        $wre26
                        [
                            string-length(.) > 40
                            and
                            @contextRef = $thisContextId
                        ]
                     )"/>


    <!-- Rule ID: VR.ATO.WRE.000009
         ELS Ref: V7

		    IF (LENGTH([wre28])) > 240
             RETURN VALIDATION MESSAGE
        ENDIF

		    [wre28] = rvctc2.xx.xx:IncomeTax.Deduction.TravelStandardEvidenceCalculationOther.Description
    -->
    <assert id="VR.ATO.WRE.000009" diagnostics="DVR.ATO.WRE.000009"
            test="not(
                        $wre28
                        [
                            string-length(.) > 240
                            and
                            @contextRef = $thisContextId
                        ]
                     )"/>


    <!-- Rule ID: VR.ATO.WRE.000010
         ELS Ref: V7

		    IF ANY OCCURRENCE OF ([wre29] <> MONETARY(U,11,0))
		         RETURN VALIDATION MESSAGE
		    ENDIF

		    [wre29] = rvctc2.xx.xx:IncomeTax.Deduction.Travel.Amount
    -->
    <assert id="VR.ATO.WRE.000010" diagnostics="DVR.ATO.WRE.000010"
            test="not(
                        $wre29
                        [
                            not(matches(.,'^[0-9]{1,11}$'))
                            and
                            @contextRef = $thisContextId
                        ]
                     )"/>

  </rule>

  <!-- LOOP OVER REPORTING PARTY CLOTHING SEQUENCE DIMENSION CONTEXT -->
  <rule context="xbrli:xbrl/xbrli:context[@id = $RPCLOTHINGSEQ.ContextId]">

    <let name="thisContextId" value="@id" />

    <!-- Rule ID: VR.ATO.WRE.000011
         ELS Ref: V7

		    IF (LENGTH([wre33])) > 40
             RETURN VALIDATION MESSAGE
        ENDIF

		    [wre33] = rvctc2.xx.xx:IncomeTax.Deduction.ClothingCategoryOther.Description
    -->
    <assert id="VR.ATO.WRE.000011" diagnostics="DVR.ATO.WRE.000011"
            test="not(
                        $wre33
                        [
                            string-length(.) > 40
                            and
                            @contextRef = $thisContextId
                        ]
                     )"/>


    <!-- Rule ID: VR.ATO.WRE.000012
         ELS Ref: V7

		    IF (LENGTH([wre35])) > 240
             RETURN VALIDATION MESSAGE
        ENDIF

		    [wre35] = rvctc2.xx.xx:IncomeTax.Deduction.ClothingStandardEvidenceCalculationOther.Description
    -->
    <assert id="VR.ATO.WRE.000012" diagnostics="DVR.ATO.WRE.000012"
            test="not(
                        $wre35
                        [
                            string-length(.) > 240
                            and
                            @contextRef = $thisContextId
                        ]
                     )"/>


    <!-- Rule ID: VR.ATO.WRE.000013
         ELS Ref: V7

		    IF ([wre36] <> MONETARY(U,11,0))
             RETURN VALIDATION MESSAGE
        ENDIF

		    [wre36] = rvctc2.xx.xx:IncomeTax.Deduction.Clothing.Amount
    -->
    <assert id="VR.ATO.WRE.000013" diagnostics="DVR.ATO.WRE.000013"
            test="not(
                        $wre36
                        [
                            not(matches(.,'^[0-9]{1,11}$'))
                            and
                            @contextRef = $thisContextId
                        ]
                     )"/>

  </rule>

  <!-- LOOP OVER REPORTING PARTY EDUCATION SEQUENCE DIMENSION CONTEXT -->
  <rule context="xbrli:xbrl/xbrli:context[@id = $RPEDUCATIONSEQ.ContextId]">

    <let name="thisContextId" value="@id" />

    <!-- Rule ID: VR.ATO.WRE.000015
         ELS Ref: V7

		    IF (LENGTH([wre39])) > 20
           RETURN VALIDATION MESSAGE
        ENDIF

		    [wre39] = pyid.xx.xx:Identifiers.CourseName.Text
    -->
    <assert id="VR.ATO.WRE.000015" diagnostics="DVR.ATO.WRE.000015"
            test="not(
                        $wre39
                        [
                            string-length(.) > 20
                            and
                            @contextRef = $thisContextId
                        ]
                     )"/>


    <!-- Rule ID: VR.ATO.WRE.000016
         ELS Ref: V7

		    IF (LENGTH([wre40])) > 20
             RETURN VALIDATION MESSAGE
        ENDIF

		    [wre40] = pyid.xx.xx:Identifiers.InstitutionName.Text
    -->
    <assert id="VR.ATO.WRE.000016" diagnostics="DVR.ATO.WRE.000016"
            test="not(
                        $wre40
                        [
                            string-length(.) > 20
                            and
                            @contextRef = $thisContextId
                        ]
                     )"/>


    <!-- Rule ID: VR.ATO.WRE.000017
         ELS Ref: V7

		    IF (LENGTH([wre42])) > 40
             RETURN VALIDATION MESSAGE
        ENDIF

		    [wre42] = rvctc2.xx.xx:IncomeTax.Deduction.EducationCategoryOther.Description
    -->
    <assert id="VR.ATO.WRE.000017" diagnostics="DVR.ATO.WRE.000017"
            test="not(
                        $wre42
                        [
                            string-length(.) > 40
                            and
                            @contextRef = $thisContextId
                        ]
                     )"/>
    
    
    <!-- Rule ID: VR.ATO.WRE.000018
         ELS Ref: V7

		    IF (LENGTH([wre44])) > 240
             RETURN VALIDATION MESSAGE
        ENDIF

		    [wre44] = rvctc2.xx.xx:IncomeTax.Deduction.EducationStandardEvidenceCalculationOther.Description
    -->
    <assert id="VR.ATO.WRE.000018" diagnostics="DVR.ATO.WRE.000018"
            test="not(
                        $wre44
                        [
                            string-length(.) > 240
                            and
                            @contextRef = $thisContextId
                        ]
                     )"/>
    
    
    <!-- Rule ID: VR.ATO.WRE.000019
         ELS Ref: V7

		    IF ([wre45] <> MONETARY(U,11,0))
             RETURN VALIDATION MESSAGE
        ENDIF

		    [wre45] = rvctc2.xx.xx:IncomeTax.Deduction.Education.Amount
    -->
    <assert id="VR.ATO.WRE.000019" diagnostics="DVR.ATO.WRE.000019"
            test="not(
                        $wre45
                        [
                            not(matches(.,'^[0-9]{1,11}$'))
                            and
                            @contextRef = $thisContextId
                        ]
                     )"/>
    
  </rule>
  
  <!-- LOOP OVER REPORTING PARTY OTHER WRE SEQUENCE DIMENSION CONTEXT -->
  <rule context="xbrli:xbrl/xbrli:context[@id = $RPOTHERWRESEQ.ContextId]">

    <let name="thisContextId" value="@id" />

    <!-- Rule ID: VR.ATO.WRE.000022
         ELS Ref: V7

		    IF (LENGTH([wre51])) > 40
             RETURN VALIDATION MESSAGE
        ENDIF

		    [wre51] = rvctc2.xx.xx:IncomeTax.Deduction.WorkRelatedCategoryOther.Description
    -->
    <assert id="VR.ATO.WRE.000022" diagnostics="DVR.ATO.WRE.000022"
            test="not(
                        $wre51
                        [
                            string-length(.) > 40
                            and
                            @contextRef = $thisContextId
                        ]
                     )"/>
    
    
    <!-- Rule ID: VR.ATO.WRE.000025
         ELS Ref: V7

		    IF ([wre55] <> MONETARY(U,11,0))
             RETURN  VALIDATION MESSAGE
        ENDIF

		    [wre55] = rvctc2.xx.xx:IncomeTax.Deduction.WorkRelatedOther.Amount
    -->
    <assert id="VR.ATO.WRE.000025" diagnostics="DVR.ATO.WRE.000025"
            test="not(
                        $wre55
                        [
                            not(matches(.,'^[0-9]{1,11}$'))
                            and
                            @contextRef = $thisContextId
                        ]
                     )"/>

    
    <!-- Rule ID: VR.ATO.WRE.000023
         ELS Ref: V7

        IF (LENGTH([wre52])) > 3
             RETURN VALIDATION MESSAGE
        ENDIF

		    [wre52] = rvctc2.02.14:IncomeTax.Deduction.WorkRelatedBusinessUseClaimedOther.Percent
    -->
    <assert id="VR.ATO.WRE.000023" diagnostics="DVR.ATO.WRE.000023"
            test="not(
                        $wre52
                        [
                            string-length(.) > 3
                            and
                            @contextRef = $thisContextId
                        ]
                     )"/>
    
    
    <!-- Rule ID: VR.ATO.WRE.000024
         ELS Ref: V7

        IF (LENGTH([wre54])) > 240
             RETURN VALIDATION MESSAGE
        ENDIF

		    [wre54] = rvctc2.02.14:IncomeTax.Deduction.WorkRelatedStandardEvidenceCalculationOther.Description
    -->
    <assert id="VR.ATO.WRE.000024" diagnostics="DVR.ATO.WRE.000024"
            test="not(
                        $wre54
                        [
                            string-length(.) > 240
                            and
                            @contextRef = $thisContextId
                        ]
                     )"/> 
  </rule>

</pattern>